==> webkit2gtk_2.25.1.orig.tar.xz: webkitgtk-2.25.1/Source/WebCore/Modules/webgpu/WHLSL/WHLSLSemanticMatcher.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "WHLSLGatherEntryPointItems.h"
#include "WHLSLPipelineDescriptor.h"
#include <wtf/HashMap.h>

namespace WebCore {

namespace WHLSL {

class Program;

struct MatchedRenderSemantics {
    AST::FunctionDefinition* vertexShader;
    AST::FunctionDefinition* fragmentShader;
    EntryPointItems vertexShaderEntryPointItems;
    EntryPointItems fragmentShaderEntryPointItems;
    HashMap<Binding*, size_t> vertexShaderResourceMap;
    HashMap<Binding*, size_t> fragmentShaderResourceMap;
    HashMap<VertexAttribute*, size_t> matchedVertexAttributes;
    HashMap<AttachmentDescriptor*, size_t> matchedColorAttachments;
};

Optional<MatchedRenderSemantics> matchSemantics(Program&, RenderPipelineDescriptor&);

struct MatchedComputeSemantics {
    AST::FunctionDefinition* shader;
    EntryPointItems entryPointItems;
    HashMap<Binding*, size_t> resourceMap;
};

Optional<MatchedComputeSemantics> matchSemantics(Program&, ComputePipelineDescriptor&);

} // namespace WHLSL

} // namespace WebCore

#endif // ENABLE(WEBGPU)

==> webkit2gtk_2.30.3.orig.tar.xz: webkitgtk-2.30.3/Source/WebCore/Modules/webgpu/WHLSL/WHLSLSemanticMatcher.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "WHLSLGatherEntryPointItems.h"
#include "WHLSLPipelineDescriptor.h"
#include <wtf/HashMap.h>

namespace WebCore {

namespace WHLSL {

class Program;

struct MatchedRenderSemantics {
    AST::FunctionDefinition* vertexShader;
    AST::FunctionDefinition* fragmentShader;
    EntryPointItems vertexShaderEntryPointItems;
    EntryPointItems fragmentShaderEntryPointItems;
    HashMap<Binding*, size_t> vertexShaderResourceMap;
    HashMap<Binding*, size_t> fragmentShaderResourceMap;
    HashMap<VertexAttribute*, size_t> matchedVertexAttributes;
    HashMap<AttachmentDescriptor*, size_t> matchedColorAttachments;
};

Optional<MatchedRenderSemantics> matchSemantics(Program&, RenderPipelineDescriptor&, bool distinctFragmentShader, bool fragmentShaderExists);

struct MatchedComputeSemantics {
    AST::FunctionDefinition* shader;
    EntryPointItems entryPointItems;
    HashMap<Binding*, size_t> resourceMap;
};

Optional<MatchedComputeSemantics> matchSemantics(Program&, ComputePipelineDescriptor&);

} // namespace WHLSL

} // namespace WebCore

#endif // ENABLE(WEBGPU)
